FileListener

Struct FileListener 

pub struct FileListener { /* private fields */ }
A listener that monitors a file for changes and captures new lines.

Use tick() to poll for changes.

Implementations

Source

impl FileListener

pub fn builder<P: AsRef<Path>>(path: P) -> FileListenerBuilder

Creates a new FileListenerBuilder for the given file path.

pub fn tick(&mut self) -> Result<()>

Checks the file for changes and updates the internal line buffer.

This method handles:

  • Connecting to the file if it appears.
  • Backfilling lines on the first connection.
  • Detecting truncation or modification and resetting if necessary.
  • Appending new lines as they are written.
Errors

Returns an [Error] if filesystem operations fail (other than NotFound, which is handled gracefully).

pub const fn lines(&self) -> &VecDeque<(DateTime<Utc>, String)>

Returns an immutable reference to the internal buffer of lines.

pub fn len(&self) -> usize

Returns the number of buffered lines.

pub fn is_empty(&self) -> bool

Returns true if there are no buffered lines.

pub fn clear(&mut self)

Clears all buffered lines.

pub fn drain(&mut self) -> Drain<'_, (DateTime<Utc>, String)>

Drains and yields all buffered lines.

pub fn path(&self) -> &Path

Returns the watched path.